"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const ecs = new aws_sdk_1.default.ECS({
    apiVersion: '2014-11-13',
    region: 'eu-west-1',
});
function createService(opts, name, env) {
    return new Promise((resolve, reject) => {
        const params = {
            cluster: `${opts.stack}-${opts.type}-${env}`,
            serviceName: `${name}-${env}`,
            taskDefinition: `${opts.stack}-${opts.type}-${env}-${name}`,
            desiredCount: opts[env].desiredCount,
            launchType: 'FARGATE',
            networkConfiguration: {
                awsvpcConfiguration: {
                    subnets: opts[env].subnets,
                    assignPublicIp: 'DISABLED',
                },
            },
        };
        ecs.createService(params, (err, res) => {
            if (err)
                reject(err);
            else
                resolve(res);
        });
    });
}
function updateService(opts, name, env) {
    return new Promise((resolve, reject) => {
        const params = {
            cluster: `${opts.stack}-${opts.type}-${env}`,
            service: `${name}-${env}`,
            desiredCount: opts[env].desiredCount,
            forceNewDeployment: true
        };
        ecs.updateService(params, (err, res) => {
            if (err)
                reject(err);
            else
                resolve(res);
        });
    });
}
async function updateECSService(opts, name, env) {
    // can we update the service?
    try {
        const res = await updateService(opts, name, env);
        console.log('Service updated');
        return res;
    }
    catch (e) {
        if (e.statusCode === 400) {
            console.log('Service not found, trying to create it...');
        }
        else {
            return e;
        }
    }
    try {
        await createService(opts, name, env);
        console.log('Service created');
        return 'created';
    }
    catch (e) {
        console.log(e);
        return e;
    }
}
exports.default = updateECSService;
//# sourceMappingURL=updateECSService.js.map